package com.ygtx.gxt.service;

import java.util.List;
import com.ygtx.gxt.domain.GxtRepairOrderPerson;

/**
 * 维修工单工作组员名单Service接口
 * 
 * @author ouyj
 * @date 2025-11-01
 */
public interface IGxtRepairOrderPersonService 
{
    /**
     * 查询维修工单工作组员名单
     * 
     * @param id 维修工单工作组员名单主键
     * @return 维修工单工作组员名单
     */
    public GxtRepairOrderPerson selectGxtRepairOrderPersonById(Long id);

    /**
     * 查询维修工单工作组员名单列表
     * 
     * @param gxtRepairOrderPerson 维修工单工作组员名单
     * @return 维修工单工作组员名单集合
     */
    public List<GxtRepairOrderPerson> selectGxtRepairOrderPersonList(GxtRepairOrderPerson gxtRepairOrderPerson);

    /**
     * 新增维修工单工作组员名单
     * 
     * @param gxtRepairOrderPerson 维修工单工作组员名单
     * @return 结果
     */
    public int insertGxtRepairOrderPerson(GxtRepairOrderPerson gxtRepairOrderPerson);

    /**
     * 修改维修工单工作组员名单
     * 
     * @param gxtRepairOrderPerson 维修工单工作组员名单
     * @return 结果
     */
    public int updateGxtRepairOrderPerson(GxtRepairOrderPerson gxtRepairOrderPerson);

    /**
     * 批量删除维修工单工作组员名单
     * 
     * @param ids 需要删除的维修工单工作组员名单主键集合
     * @return 结果
     */
    public int deleteGxtRepairOrderPersonByIds(Long[] ids);

    /**
     * 删除维修工单工作组员名单信息
     * 
     * @param id 维修工单工作组员名单主键
     * @return 结果
     */
    public int deleteGxtRepairOrderPersonById(Long id);
}
