package com.ygtx.gxt.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ygtx.common.annotation.Log;
import com.ygtx.common.core.controller.BaseController;
import com.ygtx.common.core.domain.AjaxResult;
import com.ygtx.common.enums.BusinessType;
import com.ygtx.gxt.domain.GxtRepairOrderPerson;
import com.ygtx.gxt.service.IGxtRepairOrderPersonService;
import com.ygtx.common.utils.poi.ExcelUtil;
import com.ygtx.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;

/**
 * 维修工单工作组员名单Controller
 * 
 * @author ouyj
 * @date 2025-11-01
 */
@RestController
@RequestMapping("/gxt/repairOrderPerson")
@Api(tags = "维修工单工作组员名单")
public class GxtRepairOrderPersonController extends BaseController
{
    @Autowired
    private IGxtRepairOrderPersonService gxtRepairOrderPersonService;

    /**
     * 查询维修工单工作组员名单列表
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderPerson:list')")
    @ApiOperation("查询维修工单工作组员名单列表")
    @GetMapping("/list")
    public TableDataInfo list(GxtRepairOrderPerson gxtRepairOrderPerson)
    {
        startPage();
        List<GxtRepairOrderPerson> list = gxtRepairOrderPersonService.selectGxtRepairOrderPersonList(gxtRepairOrderPerson);
        return getDataTable(list);
    }

    /**
     * 导出维修工单工作组员名单列表
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderPerson:export')")
    @Log(title = "维修工单工作组员名单", businessType = BusinessType.EXPORT)
    @ApiOperation("导出维修工单工作组员名单列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, GxtRepairOrderPerson gxtRepairOrderPerson)
    {
        List<GxtRepairOrderPerson> list = gxtRepairOrderPersonService.selectGxtRepairOrderPersonList(gxtRepairOrderPerson);
        ExcelUtil<GxtRepairOrderPerson> util = new ExcelUtil<GxtRepairOrderPerson>(GxtRepairOrderPerson.class);
        util.exportExcel(response, list, "维修工单工作组员名单数据");
    }

    /**
     * 获取维修工单工作组员名单详细信息
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderPerson:query')")
    @ApiOperation("获取维修工单工作组员名单详细信息")
    @ApiImplicitParam(name = "id", value = "主键ID", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gxtRepairOrderPersonService.selectGxtRepairOrderPersonById(id));
    }

    /**
     * 新增维修工单工作组员名单
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderPerson:add')")
    @Log(title = "维修工单工作组员名单", businessType = BusinessType.INSERT)
    @ApiOperation("新增维修工单工作组员名单")
    @PostMapping
    public AjaxResult add(@RequestBody GxtRepairOrderPerson gxtRepairOrderPerson)
    {
        return toAjax(gxtRepairOrderPersonService.insertGxtRepairOrderPerson(gxtRepairOrderPerson));
    }

    /**
     * 修改维修工单工作组员名单
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderPerson:edit')")
    @Log(title = "维修工单工作组员名单", businessType = BusinessType.UPDATE)
    @ApiOperation("修改维修工单工作组员名单")
    @PutMapping
    public AjaxResult edit(@RequestBody GxtRepairOrderPerson gxtRepairOrderPerson)
    {
        return toAjax(gxtRepairOrderPersonService.updateGxtRepairOrderPerson(gxtRepairOrderPerson));
    }

    /**
     * 删除维修工单工作组员名单
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderPerson:remove')")
    @Log(title = "维修工单工作组员名单", businessType = BusinessType.DELETE)
    @ApiOperation("删除维修工单工作组员名单")
    @ApiImplicitParam(name = "ids", value = "主键ID数组", required = true, dataType = "Long[]", paramType = "path", dataTypeClass = Long[].class)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gxtRepairOrderPersonService.deleteGxtRepairOrderPersonByIds(ids));
    }
}